import { r as registerInstance, h, H as Host, g as getElement, c as createEvent } from './index-416188d1.js';
import { h as hasShadowDom, a as hasSlot } from './utils-3f3d360c.js';

const ruxButtonCss = ":host{display:inline-block;width:auto}:host([hidden]){display:none}:host([disabled]){pointer-events:none}.rux-button{border:none;display:flex;position:relative;margin:var(--spacing-0, 0rem);width:inherit;padding:var(--spacing-2, 0.5rem) var(--spacing-4, 1rem);border-radius:var(--radius-base, 3px);color:var(--color-text-inverse, #080c11);font-family:var(--font-control-body-1-font-family, 'Roboto', -apple-system, BlinkMacSystemFont, 'Segoe UI', Oxygen-Sans, Ubuntu, Cantarell, 'Helvetica Neue', sans-serif);font-size:var(--font-control-body-1-font-size, 1rem);font-weight:var(--font-control-body-1-font-weight, 400);line-height:var(--font-control-body-1-line-height, calc(20 / 16));letter-spacing:var(--font-control-body-1-letter-spacing, 0.005em);white-space:nowrap;text-overflow:ellipsis;justify-content:center;align-items:center;user-select:none}.rux-button rux-icon,.rux-button ::slotted(rux-icon){height:calc(var(--spacing-4, 1rem) + var(--spacing-1, 0.25rem));width:calc(var(--spacing-4, 1rem) + var(--spacing-1, 0.25rem));margin-right:var(--spacing-1, 0.25rem);color:var(--color-text-inverse, #080c11)}.rux-button:disabled{opacity:var(--opacity-disabled, 40%);cursor:not-allowed;pointer-events:none}.rux-button:focus-visible{outline:var(--border-width-focus-default, 1px) solid var(--color-border-focus-default, #da9ce7);outline-offset:var(--spacing-focus-default, 0.125rem)}.rux-button:hover:not([disabled]){cursor:pointer}.rux-button--default{background-color:var(--color-background-interactive-default, #4dacff)}.rux-button--default:hover:not([disabled]){border-color:transparent;background-color:var(--color-background-interactive-hover, #92cbff)}.rux-button--default:active:not([disabled]){border-color:var(--color-background-interactive-default, #4dacff);background-color:var(--color-background-interactive-default, #4dacff)}.rux-button--secondary{color:var(--color-background-interactive-default, #4dacff);background-color:transparent;box-shadow:var(--color-border-interactive-default, #4dacff) 0 0 0 1px inset}.rux-button--secondary:hover:not([disabled]){color:var(--color-background-interactive-hover, #92cbff);background-color:transparent;box-shadow:var(--color-background-interactive-hover, #92cbff) 0 0 0 1px inset}.rux-button--secondary:hover:not([disabled]) rux-icon,.rux-button--secondary:hover:not([disabled]) ::slotted(rux-icon){color:var(--color-background-interactive-hover, #92cbff)}.rux-button--secondary:active:not([disabled]){box-shadow:var(--color-background-interactive-default, #4dacff) 0 0 0 1px inset;background-color:transparent;color:var(--color-background-interactive-default, #4dacff)}.rux-button--secondary:active:not([disabled]) rux-icon,.rux-button--secondary:active:not([disabled]) ::slotted(rux-icon){color:var(--color-background-interactive-default, #4dacff)}.rux-button--secondary rux-icon,.rux-button--secondary ::slotted(rux-icon){color:var(--color-background-interactive-default, #4dacff)}.rux-button--borderless{color:var(--color-background-interactive-default, #4dacff);box-shadow:none;background:none}.rux-button--borderless:hover:not([disabled]){color:var(--color-background-interactive-hover, #92cbff);background:none}.rux-button--borderless:hover:not([disabled]) rux-icon,.rux-button--borderless:hover:not([disabled]) ::slotted(rux-icon){color:var(--color-background-interactive-hover, #92cbff)}.rux-button--borderless:active:not([disabled]){color:var(--color-background-interactive-default, #4dacff)}.rux-button--borderless:active:not([disabled]) rux-icon,.rux-button--borderless:active:not([disabled]) ::slotted(rux-icon){color:var(--color-background-interactive-default, #4dacff)}.rux-button--borderless rux-icon,.rux-button--borderless ::slotted(rux-icon){color:var(--color-background-interactive-default, #4dacff)}.rux-button--small{padding:var(--spacing-1, 0.25rem) var(--spacing-4, 1rem)}.rux-button--small.rux-button--icon-only{padding:var(--spacing-1, 0.25rem)}.rux-button--large{padding:var(--spacing-3, 0.75rem) var(--spacing-4, 1rem)}.rux-button--large.rux-button--icon-only{padding:var(--spacing-3, 0.75rem)}.rux-button--icon-only{font-size:0;padding:var(--spacing-2, 0.5rem)}.rux-button--icon-only ::slotted(rux-icon),.rux-button--icon-only rux-icon{margin:0}";

const RuxButton = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    /**
     * Creates and appends a native <button> if used within a form
     * so that it can trigger the submit event.
     *
     * Shadow DOM limitation prevents <form> from working correctly.
     * https://github.com/ionic-team/ionic-framework/blob/main/core/src/components/button/button.tsx
     * @param ev
     */
    this.handleClick = (ev) => {
      if (hasShadowDom(this.el)) {
        const form = this.el.closest('form');
        if (form) {
          ev.preventDefault();
          const fakeButton = document.createElement('button');
          fakeButton.type = this.type;
          fakeButton.style.display = 'none';
          form.appendChild(fakeButton);
          fakeButton.click();
          fakeButton.remove();
        }
      }
    };
    this.icon = undefined;
    this.iconOnly = false;
    this.secondary = false;
    this.disabled = false;
    this.borderless = false;
    this.size = undefined;
    this.type = 'button';
  }
  render() {
    const { size, iconOnly, secondary, disabled, icon, borderless } = this;
    return (h(Host, null, h("button", { type: "button", onClick: this.handleClick, class: {
        'rux-button': true,
        'rux-button--secondary': secondary,
        'rux-button--default': !secondary,
        'rux-button--small': size === 'small',
        'rux-button--large': size === 'large',
        'rux-button--icon-only': iconOnly,
        'rux-button--borderless': borderless,
      }, "aria-disabled": disabled ? 'true' : null, disabled: disabled, part: "container" }, icon ? (h("rux-icon", { size: "auto", icon: icon, exportparts: "icon", color: secondary ? 'primary' : 'dark' })) : null, h("slot", null))));
  }
  static get delegatesFocus() { return true; }
  get el() { return getElement(this); }
};
RuxButton.style = ruxButtonCss;

const ruxIconCss = ":host{display:inline-flex;color:var(--color-background-interactive-default, #4dacff)}:host([hidden]){display:none}svg,svg>svg{height:100%;width:auto}.icon{display:inline-flex}";

const RuxIcon = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    // eslint-disable-next-line
    this.svg = '';
    this.size = 'normal';
    this.icon = undefined;
  }
  render() {
    const SVG = `rux-icon-${this.icon}`;
    return (h(Host, null, h(SVG, { class: "icon", part: "icon", size: this.size })));
  }
};
RuxIcon.style = ruxIconCss;

const caution = '<svg viewBox="0 0 12 12" fill="none" xmlns="http://www.w3.org/2000/svg"><rect x="2" y="2" width="8" height="8" fill="var(--caution-fill, #fce83a)" stroke="var(--caution-border, #fce83a)"/></svg>';

const critical = '<svg viewBox="0 0 12 12" fill="none" xmlns="http://www.w3.org/2000/svg"><path d="M6.00012 10.9558L0.842393 1.5L11.1579 1.5L6.00012 10.9558Z" fill="var(--critical-fill, #ff3838)" stroke="var(--critical-border, #ff3838)"/></svg>';

const normal = '<svg viewBox="0 0 12 12" fill="none" xmlns="http://www.w3.org/2000/svg"><circle cx="6" cy="6" r="4" fill="var(--normal-fill, #56f000)" stroke="var(--normal-border, #56f000)"/></svg>';

const off = '<svg viewBox="0 0 12 12" fill="none" xmlns="http://www.w3.org/2000/svg"><circle cx="6" cy="6" r="3" fill="var(--off-fill, #a4abb6)" stroke="var(--off-border, #a4abb6)"/></svg>';

const serious = '<svg viewBox="0 0 12 12" fill="none" xmlns="http://www.w3.org/2000/svg"><rect x="1.05029" y="6" width="7.3" height="7.3" transform="rotate(-45 1.05029 6)" fill="var(--serious-fill, #ffb302)" stroke="var(--serious-border, #ffb302)"/></svg>';

const standby = '<svg viewBox="0 0 12 12" fill="none" xmlns="http://www.w3.org/2000/svg"><path fill-rule="evenodd" clip-rule="evenodd" d="M5.99988 10C8.20902 10 9.99988 8.20914 9.99988 6C9.99988 3.79086 8.20902 2 5.99988 2C3.79074 2 1.99988 3.79086 1.99988 6C1.99988 8.20914 3.79074 10 5.99988 10ZM5.99996 7.99999C7.10453 7.99999 7.99996 7.10456 7.99996 5.99999C7.99996 4.89542 7.10453 3.99999 5.99996 3.99999C4.89539 3.99999 3.99996 4.89542 3.99996 5.99999C3.99996 7.10456 4.89539 7.99999 5.99996 7.99999Z" fill="var(--standby-fill, #2dccff)"/><path d="M10 6C10 8.20914 8.20914 10 6 10V11C8.76142 11 11 8.76142 11 6H10ZM6 2C8.20914 2 10 3.79086 10 6H11C11 3.23858 8.76142 1 6 1V2ZM2 6C2 3.79086 3.79086 2 6 2V1C3.23858 1 1 3.23858 1 6H2ZM6 10C3.79086 10 2 8.20914 2 6H1C1 8.76142 3.23858 11 6 11V10ZM7 6C7 6.55228 6.55228 7 6 7V8C7.10457 8 8 7.10457 8 6H7ZM6 5C6.55228 5 7 5.44772 7 6H8C8 4.89543 7.10457 4 6 4V5ZM5 6C5 5.44772 5.44772 5 6 5V4C4.89543 4 4 4.89543 4 6H5ZM6 7C5.44772 7 5 6.55228 5 6H4C4 7.10457 4.89543 8 6 8V7Z" fill="var(--standby-border, #2dccff)" fill-opacity="var(--standby-fill-opacity, 0)"/></svg>';

const StatusSVG = {
  caution,
  critical,
  normal,
  off,
  serious,
  standby,
};

const ruxStatusCss = ":host{display:block}:host([hidden]){display:none}*,*::before,*::after{box-sizing:border-box}.status-wrapper{width:var(--spacing-3, 0.75rem);font-family:var(--font-body-1-font-family, 'Roboto', -apple-system, BlinkMacSystemFont, 'Segoe UI', Oxygen-Sans, Ubuntu, Cantarell, 'Helvetica Neue', sans-serif);font-size:var(--font-body-1-font-size, 1rem);font-weight:var(--font-body-1-font-weight, 400);letter-spacing:var(--font-body-1-letter-spacing, 0.005em);line-height:var(--line-height-base, 1.5rem)}";

const RuxStatus = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    this.status = 'normal';
  }
  validateStatus(newValue) {
    const statusTypes = {
      off: true,
      standby: true,
      normal: true,
      caution: true,
      serious: true,
      critical: true,
    };
    if (!statusTypes[newValue]) {
      throw new Error(`rux-status: status of ${this.status} is not valid. Please use a valid status.`);
    }
  }
  connectedCallback() {
    if (this.status)
      this.validateStatus(this.status);
  }
  render() {
    return (h(Host, { status: this.status }, h("div", { part: "status", class: "status-wrapper", innerHTML: this.status && StatusSVG[this.status] })));
  }
  get el() { return getElement(this); }
  static get watchers() { return {
    "status": ["validateStatus"]
  }; }
};
RuxStatus.style = ruxStatusCss;

const ruxToastCss = ":host{display:contents;--height:auto;--iconSize:16px}.rux-toast{display:flex;align-items:center;align-content:center;box-sizing:border-box;width:calc((var(--spacing-20, 5rem) * 3) + (var(--spacing-10, 2.5rem)));border-radius:var(--radius-base, 3px);background:var(--color-background-base-default, #101923);padding:calc(var(--spacing-4, 1rem) + var(--spacing-050, 0.125rem)) var(--spacing-2, 0.5rem) calc(var(--spacing-4, 1rem) + var(--spacing-050, 0.125rem)) var(--spacing-4, 1rem);margin-block-start:var(--spacing-3, 0.75rem);min-height:calc(var(--spacing-14, 3.5rem) + var(--spacing-1, 0.25rem));height:var(--height);border:var(--border-width-xs, 1px) solid var(--color-border-interactive-default, #4dacff);font-family:var(--font-body-1-font-family, 'Roboto', -apple-system, BlinkMacSystemFont, 'Segoe UI', Oxygen-Sans, Ubuntu, Cantarell, 'Helvetica Neue', sans-serif);font-size:var(--font-body-1-font-size, 1rem);font-weight:var(--font-body-1-font-weight, 400);letter-spacing:var(--font-body-1-letter-spacing, 0.005em);line-height:var(--line-height-base, 1.5rem);opacity:inherit}.rux-toast__actions{margin-left:auto;margin-bottom:auto;display:flex}.rux-toast__close:focus-visible{border-radius:var(--radius-base, 3px);outline:var(--border-width-focus-default, 1px) solid var(--color-border-focus-default, #da9ce7);outline-offset:var(--spacing-focus-default, 0.125rem)}.rux-toast__content{display:flex;justify-content:center;align-items:center;gap:var(--spacing-4, 1rem)}.rux-toast__close{cursor:pointer}.rux-toast.rux-toast-status__standby{border-color:var(--color-status-standby, #2dccff)}.rux-toast.rux-toast-status__standby rux-icon::part(icon){color:var(--color-status-standby, #2dccff)}.rux-toast.rux-toast-status__critical{border-color:var(--color-status-critical, #ff3838)}.rux-toast.rux-toast-status__critical rux-icon::part(icon){color:var(--color-status-critical, #ff3838)}.rux-toast.rux-toast-status__serious{border-color:var(--color-status-serious, #ffb302)}.rux-toast.rux-toast-status__serious rux-icon::part(icon){color:var(--color-status-serious, #ffb302)}.rux-toast.rux-toast-status__caution{border-color:var(--color-status-caution, #fce83a)}.rux-toast.rux-toast-status__caution rux-icon::part(icon){color:var(--color-status-caution, #fce83a)}.rux-toast.rux-toast-status__off{border-color:var(--color-status-off, #a4abb6)}.rux-toast.rux-toast-status__off rux-icon::part(icon){color:var(--color-status-off, #a4abb6)}.rux-toast.rux-toast-status__normal{border-color:var(--color-status-normal, #56f000)}.rux-toast.rux-toast-status__normal rux-icon::part(icon){color:var(--color-status-normal, #56f000)}";

const RuxToast = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    this.ruxToastOpen = createEvent(this, "ruxtoastopen", 7);
    this.ruxToastClosed = createEvent(this, "ruxtoastclosed", 7);
    this._timeoutRef = null;
    this.hasMessageSlot = false;
    this.message = '';
    this.closeAfter = undefined;
    this.hideClose = false;
    this.status = undefined;
  }
  watchHandler() {
    this._updated();
  }
  connectedCallback() {
    this._handleSlotChange = this._handleSlotChange.bind(this);
    this._updated();
    this.hasMessageSlot = hasSlot(this.el);
    this._onClick = this._onClick.bind(this);
    this._onKeyPress = this._onKeyPress.bind(this);
  }
  componentDidLoad() {
    this._handleOpen();
  }
  _handleOpen() {
    this.ruxToastOpen.emit();
  }
  _handleClose() {
    this.ruxToastClosed.emit();
    this.el.remove();
  }
  _updated() {
    if (this._closeAfter) {
      this._timeoutRef = window.setTimeout(() => {
        this._handleClose();
      }, this._closeAfter);
    }
  }
  _onClick() {
    if (this._timeoutRef) {
      clearTimeout(this._timeoutRef);
    }
    this._handleClose();
  }
  _onKeyPress(e) {
    if (e.key === 'Enter') {
      this._onClick();
    }
  }
  get _closeAfter() {
    //* as long as it's less than 1000, they put in seconds. Convert that here.
    if (this.closeAfter && this.closeAfter <= 999) {
      //it's in seconds
      this.closeAfter *= 1000; // change into ms
    }
    if ((this.closeAfter && this.closeAfter > 10000) ||
      (this.closeAfter && this.closeAfter < 2000)) {
      // if this number is larger than 10s or smaller than 2s, enforce minimum 2s delay
      this.closeAfter = 2000;
    }
    return this.closeAfter;
  }
  _handleSlotChange() {
    this.hasMessageSlot = hasSlot(this.el);
  }
  render() {
    return (h(Host, null, h("div", { class: `rux-toast rux-toast-status__${this.status}`, part: "container" }, h("div", { class: {
        'rux-toast__content': true,
      }, part: "message" }, this.status ? (h("rux-status", { status: this.status })) : null, h("slot", { onSlotchange: this._handleSlotChange }), !this.hasMessageSlot && this.message ? (h("span", null, this.message)) : null), !this.hideClose ? (h("div", { class: "rux-toast__actions" }, h("rux-icon", { role: "button", tabindex: "1", class: "rux-toast__close", onClick: this._onClick, onKeyDown: this._onKeyPress, icon: "clear", exportparts: "icon", size: getComputedStyle(this.el).getPropertyValue('--iconSize') }))) : null)));
  }
  get el() { return getElement(this); }
  static get watchers() { return {
    "closeAfter": ["watchHandler"]
  }; }
};
RuxToast.style = ruxToastCss;

const ruxToastStackCss = ":host{position:fixed;z-index:100;max-width:100%;max-height:100%;margin:var(--spacing-3, 0.75rem);margin-block-start:var(--spacing-0, 0rem);overflow:hidden}:host([position=top-right]){top:0;right:0}:host([position=top-left]){top:0;left:0}:host([position=bottom-right]){bottom:0;right:0}:host([position=bottom-left]){bottom:0;left:0}";

const RuxToastStack = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    this.position = 'top-right';
  }
  /**
   * Adds an individual toast to the stack with the set props passed in as an object.
   * Accepts any key's that match rux-toast props (message, hideClose, ect).
   */
  async addToast(props) {
    var _a;
    const toast = document.createElement('rux-toast');
    toast.style.transition = 'opacity 800ms ease-in 1s';
    for (const key in props) {
      if (props.hasOwnProperty(key)) {
        switch (key) {
          case 'message':
            toast.message = props[key];
            break;
          case 'hideClose':
            toast.hideClose = props[key];
            break;
          case 'closeAfter':
            toast.closeAfter = props[key];
            break;
          case 'status':
            toast.status = props[key];
            break;
        }
      }
    }
    (_a = this.el) === null || _a === void 0 ? void 0 : _a.insertBefore(toast, this.el.firstChild); // add as first child
  }
  get _toastsArray() {
    const toasts = Array.from(this.el.querySelectorAll('rux-toast'));
    return toasts;
  }
  render() {
    return (h(Host, null, h("div", { class: "rux-toast-stack" }, h("slot", null))));
  }
  get el() { return getElement(this); }
};
RuxToastStack.style = ruxToastStackCss;

export { RuxButton as rux_button, RuxIcon as rux_icon, RuxStatus as rux_status, RuxToast as rux_toast, RuxToastStack as rux_toast_stack };
